@@ -37,6 +37,7 @@ class ArangoPipe:
         (3) Register your featureset with ArangoPipe
         (4) Register you model with ArangoPipe
 """
+
     def __init__(self, config):
         self.cfg = config.get_cfg()
         self.emlg = None
@@ -52,7 +53,7 @@ class ArangoPipe:
             print("WARNING : " + str(e))
             logger.error(
                 "Your database was perhaps deleted, try a new connection")
-            #logger.error("Error: " + str(e))
+            # logger.error("Error: " + str(e))
             raise Exception("Your connection is stale, try a new connection!")
 
         return
@@ -114,8 +115,8 @@ class ArangoPipe:
 
         asset_info = None
         if len(asset_keys) == 0:
-            logger.info("The asset by name: " + asset_name +\
-                         " was not found in Arangopipe!")
+            logger.info("The asset by name: " + asset_name + \
+                        " was not found in Arangopipe!")
         else:
             asset_info = asset_keys[0]
 
@@ -130,8 +131,8 @@ class ArangoPipe:
 
         asset_info = None
         if len(asset_keys) == 0:
-            logger.info("The asset by name: " + asset_name +\
-                         " was not found in Arangopipe!")
+            logger.info("The asset by name: " + asset_name + \
+                        " was not found in Arangopipe!")
         else:
             asset_info = asset_keys[0]
 
@@ -188,8 +189,8 @@ class ArangoPipe:
         mp_info = None
         mp_keys = [doc for doc in cursor]
         if len(mp_keys) == 0:
-            logger.info("The model params for tag: " + tag_value +\
-                         " was not found in Arangopipe!")
+            logger.info("The model params for tag: " + tag_value + \
+                        " was not found in Arangopipe!")
         else:
             mp_info = mp_keys[0]
         return mp_info
@@ -207,8 +208,8 @@ class ArangoPipe:
         mperf_info = None
         mperf_keys = [doc for doc in cursor]
         if len(mperf_keys) == 0:
-            logger.info("The model performance for tag: " + tag_value +\
-                         " was not found in Arangopipe!")
+            logger.info("The model performance for tag: " + tag_value + \
+                        " was not found in Arangopipe!")
         else:
             mperf_info = mperf_keys[0]
 
@@ -223,24 +224,21 @@ class ArangoPipe:
         db_passwd = self.cfg['arangodb']['password']
         db_conn_protocol = self.cfg['arangodb'][self.mscp.DB_CONN_PROTOCOL]
 
-        host_conn_str =  db_conn_protocol +  "://" + \
+        host_conn_str = db_conn_protocol + "://" + \
                         db_serv_host + ":" + str(db_serv_port)
-        client = ArangoClient(hosts= host_conn_str)
+        client = ArangoClient(hosts=host_conn_str)
 
-        self.db = client.db(name= db_name, \
-                           username=db_user_name,\
-                           password=db_passwd, verify=True)
+        self.db = client.db(name=db_name, \
+                            username=db_user_name, \
+                            password=db_passwd, verify=True)
 
         self.emlg = self.db.graph(self.cfg['mlgraph']['graphname'])
 
         return
 
-
-
-
-    def register_model(self, mi, user_id = "authorized_user",\
-                       project = "Wine-Quality-Regression-Modelling"):
-        """ Register a model. The operation requires specifying a user id. If the user id is permitted to register a model, then the registration proceeds, otherwise an unauthorized operation is indicated. """
+    def register_model(self, mi, user_id="authorized_user", project="Wine-Quality-Regression-Modelling"):
+        """ Register a model. The operation requires specifying a user id. If the user id is permitted to register a
+        model, then the registration proceeds, otherwise an unauthorized operation is indicated. """
 
         model_name = mi["name"]
         try:
@@ -266,16 +264,17 @@ class ArangoPipe:
         project_model_edge = self.emlg.edge_collection("project_models")
         project_model_key = the_project_info["_key"] + "-" + model_reg["_key"]
 
-        a_project_model_edge = {"_key": project_model_key,\
-                        "_from": "project/" + the_project_info["_key"],\
-                        "_to": "models/" + model_reg["_key"]}
+        a_project_model_edge = {"_key": project_model_key, \
+                                "_from": "project/" + the_project_info["_key"], \
+                                "_to": "models/" + model_reg["_key"]}
         pm_reg = project_model_edge.insert(a_project_model_edge)
         logger.info("Recording project model link " + str(pm_reg))
 
         return model_reg
 
     def register_dataset(self, ds_info, user_id="authorized_user"):
-        """ Register a dataset. The operation requires specifying a user id. If the user id is permitted to register a dataset, then the registration proceeds, otherwise an unauthorized operation is indicated. """
+        """ Register a dataset. The operation requires specifying a user id. If the user id is permitted to register
+        a dataset, then the registration proceeds, otherwise an unauthorized operation is indicated. """
 
         ds_name = ds_info["name"]
         try:
@@ -294,10 +293,10 @@ class ArangoPipe:
 
         return ds_reg
 
-
-    def register_featureset(self, fs_info, dataset_id, \
-                            user_id = "authorized_user"):
-        """ Register a featureset. ManagedServiceConnParamThe operation requires specifying a user id. If the user id is permitted to register a featureset, then the registration proceeds, otherwise an unauthorized operation is indicated. """
+    def register_featureset(self, fs_info, dataset_id, user_id="authorized_user"):
+        """ Register a featureset. ManagedServiceConnParamThe operation requires specifying a user id. If the user id
+        is permitted to register a featureset, then the registration proceeds, otherwise an unauthorized operation is
+        indicated. """
         fs_name = fs_info["name"]
         try:
             existing_fs = self.lookup_featureset(fs_name)
@@ -317,16 +316,18 @@ class ArangoPipe:
             "featureset_dataset")
         featureset_dataset_key = fs_reg["_key"] + "-" + dataset_id
 
-        a_featureset_dataset_edge = {"_key": featureset_dataset_key,\
-                        "_from": "featuresets/" + fs_reg["_key"],\
-                        "_to": "datasets/" + dataset_id}
+        a_featureset_dataset_edge = {"_key": featureset_dataset_key, \
+                                     "_from": "featuresets/" + fs_reg["_key"], \
+                                     "_to": "datasets/" + dataset_id}
         fsds_reg = featureset_dataset_edge.insert(a_featureset_dataset_edge)
         logger.info("Recording featureset dataset link " + str(fsds_reg))
 
         return fs_reg
 
     def log_run(self, ri):
-        """ Log a run. Logging a run requires specifying a dataset, featureset and a model against which this run is recored. A run records model parameters and model performance. The run object is probably most useful for the analysis of model performance with respect to a featureset, model hyper-parameters and a dataset."""
+        """ Log a run. Logging a run requires specifying a dataset, featureset and a model against which this run is
+        recored. A run records model parameters and model performance. The run object is probably most useful for the
+        analysis of model performance with respect to a featureset, model hyper-parameters and a dataset. """
 
         rrid = ri["run_id"]
         mp = ri["model-params"]
@@ -335,70 +336,95 @@ class ArangoPipe:
         mperf["_key"] = mperf["run_id"]
         model_key = ri["model"]
 
+        run_info_adds = {"_key": rrid, "timestamp": mperf["timestamp"]}
+        default_params = ["dataset", "featureset", "model", "run_id", "model-params", "model-perf", "tag", "project",
+                          "deployment_tag"]
+        default_run_params = ["run_id", "deployment_tag"]
+
+        for key in ri:
+            if key in default_params:
+                if key in default_run_params:
+                    run_info_adds[key] = ri[key]
+            else:
+                run_info_adds[key] = ri[key]
+
         run = self.emlg.vertex_collection("run")
-        run_info = {"_key": rrid, "timestamp": mperf["timestamp"]}
-        if "deployment_tag" in ri:
-            run_info["deployment_tag"] = ri["deployment_tag"]
-        if "tag" in ri:
-            run_info["tag"] = ri["tag"]
-        logger.info("Run info " + str(run_info))
-        run_reg = run.insert(run_info)
+        # collection type
+        logger.info("Run info " + str(run_info_adds))
+        # logger
+        run_reg = run.insert(run_info_adds)
+        # insert dict into collection type
         logger.info("Recording run " + str(run_reg))
+        # logger
 
         run_model_key = run_reg["_key"] + "-" + model_key
-        a_run_model_edge = {"_key": run_model_key,\
-                            "_from" :"models/" + model_key, \
-                          "_to": "run/" + rrid}
+        # key gen
+        a_run_model_edge = {"_key": run_model_key, "_from": "models/" + model_key, "_to": "run/" + rrid}
+        # dict creation
         run_model_edge = self.emlg.edge_collection("run_models")
+        # collection type
         rme_reg = run_model_edge.insert(a_run_model_edge)
+        # insert dict into collection
         logger.info("Recording model run link " + str(rme_reg))
+        # logger
 
         model_param = self.emlg.vertex_collection("modelparams")
+        # get collection
         mp_reg = model_param.insert(mp)
+        # insert dict into collection
         logger.info("Recording model params " + str(mp_reg))
+        # logger
 
         run_fs_edge = self.emlg.edge_collection("run_featuresets")
+        # get colletion
         run_fs_key = rrid + "-" + ri["featureset"]
-
-        a_edge_run_fs = {"_key": run_fs_key,\
-                        "_from": "run/" + rrid,\
-                        "_to": "featuresets/" +  ri["featureset"]}
-
+        # gen key
+        a_edge_run_fs = {"_key": run_fs_key, "_from": "run/" + rrid, "_to": "featuresets/" + ri["featureset"]}
+        # dict gen
         rfse_reg = run_fs_edge.insert(a_edge_run_fs)
+        # insert dict into collection
         logger.info("Recording run featureset link " + str(rfse_reg))
+        # logger
 
         run_mp_edge = self.emlg.edge_collection("run_modelparams")
+        # get collection
         run_mp_key = rrid + "-" + mp["run_id"]
-
-        a_run_mp_edge = {"_key": run_mp_key,\
-                        "_from": "run/" + rrid,\
-                        "_to": "modelparams/" + mp_reg["_key"]}
-
+        # key gen
+        a_run_mp_edge = {"_key": run_mp_key, "_from": "run/" + rrid, "_to": "modelparams/" + mp_reg["_key"]}
+        # dict creation
         rmp_reg = run_mp_edge.insert(a_run_mp_edge)
+        # insert into collection
         logger.info("Recording run model params " + str(rmp_reg))
+        # logger
 
         model_perf = self.emlg.vertex_collection("devperf")
+        # get collection
         dp_reg = model_perf.insert(mperf)
+        # insert into collection
         logger.info("Recording model dev performance  " + str(dp_reg))
+        # logger
 
         run_devperf_edge = self.emlg.edge_collection("run_devperf")
+        # get collection
         run_devperf_key = rrid + "-" + dp_reg["_key"]
-
-        a_run_devperfedge = {"_key": run_devperf_key,\
-                        "_from": "run/" + rrid,\
-                        "_to": "devperf/" + dp_reg["_key"]}
+        # key gen
+        a_run_devperfedge = {"_key": run_devperf_key, "_from": "run/" + rrid, "_to": "devperf/" + dp_reg["_key"]}
+        # dict gen
         rdp_reg = run_devperf_edge.insert(a_run_devperfedge)
+        # insert into collection
         logger.info("Recording run dev perf link " + str(rdp_reg))
+        # logger
 
         run_dataset_edge = self.emlg.edge_collection("run_datasets")
+        # get collection
         run_dataset_key = rrid + "-" + ri["dataset"]
-
-        a_run_dataset_edge = {"_key": run_dataset_key,\
-                        "_from": "run/" + rrid,\
-                        "_to": "datasets/" + ri["dataset"]}
+        # key gen
+        a_run_dataset_edge = {"_key": run_dataset_key, "_from": "run/" + rrid, "_to": "datasets/" + ri["dataset"]}
+        # dict gen
         rds_reg = run_dataset_edge.insert(a_run_dataset_edge)
+        # insert into collection
         logger.info("Recording run dev perf link " + str(rds_reg))
-
+        # logger
         return
 
     def log_serving_perf(self, sp, dep_tag, userid="authorized user"):
@@ -416,9 +442,9 @@ class ArangoPipe:
         dep_servingperf_edge = self.emlg.edge_collection(
             "deployment_servingperf")
         dep_servingperf_key = the_dep_doc["_key"] + "-" + sp_reg["_key"]
-        the_dep_servingperf_edge = { "_key": dep_servingperf_key,\
-                                "_from": the_dep_doc["_id"],\
-                                "_to": sp_reg["_id"]}
+        the_dep_servingperf_edge = {"_key": dep_servingperf_key, \
+                                    "_from": the_dep_doc["_id"], \
+                                    "_to": sp_reg["_id"]}
 
         dep_servingperf_reg = dep_servingperf_edge.insert(
             the_dep_servingperf_edge)
@@ -451,9 +477,9 @@ class ArangoPipe:
                     document["_key"] = edge_key
                     edge_info = ec.insert(document)
                 else:
-                    document = { "_from": from_vdoc['_id'],\
-                                "_to": to_vdoc['_id'],\
-                                "_key": edge_key }
+                    document = {"_from": from_vdoc['_id'], \
+                                "_to": to_vdoc['_id'], \
+                                "_key": edge_key}
                     edge_info = ec.insert(document)
             except Exception as e:
                 logger.error(e)
